@@ -1673,6 +1673,19 @@ void D_DoomMain (void)
         DEH_AddStringReplacement("M_SCRNSZ", "M_DISP");
     }
 
+    //!
+    // @category game
+    // @category mod
+    //
+    // Automatic pistol start when advancing from one level to the next. At the
+    // beginning of each level, the player's health is reset to 100, their
+    // armor to 0 and their inventory is reduced to the following: pistol,
+    // fists and 50 bullets. This option is not allowed when recording a demo,
+    // playing back a demo or when starting a network game.
+    //
+
+    crispy->pistolstart = M_ParmExists("-pistolstart");
+
     //!
     // @category mod
     //
@@ -1829,6 +1842,16 @@ void D_DoomMain (void)
 
         if (D_AddFile(file))
         {
+	    int i;
+	    // [crispy] check if the demo file name gets truncated to a lump name that is already present
+	    if ((i = W_CheckNumForNameFromTo(lumpinfo[numlumps - 1]->name, numlumps - 2, 0)) != -1)
+	    {
+		printf("Demo lump name collision detected with lump \'%.8s\' from %s.\n",
+		        lumpinfo[i]->name, W_WadNameForLump(lumpinfo[i]));
+		// [FG] the DEMO1 lump is almost certainly always a demo lump
+		M_StringCopy(lumpinfo[numlumps - 1]->name, "DEMO1", 6);
+	    }
+
             M_StringCopy(demolumpname, lumpinfo[numlumps - 1]->name,
                          sizeof(demolumpname));
         }
@@ -1852,7 +1875,7 @@ void D_DoomMain (void)
     // [crispy] allow overriding of special-casing
     if (!M_ParmExists("-noautoload") && gamemode != shareware)
     {
-	if (gamemode == retail)
+	if (gamemode == retail && gameversion == exe_ultimate)
 	{
 		D_LoadSigilWad();
 	}
