@@ -868,6 +868,28 @@ void G_DoLoadLevel (void)
 		 
     // [crispy] update the "singleplayer" variable
     CheckCrispySingleplayer(!demorecording && !demoplayback && !netgame);
+
+    // [crispy] pistol start
+    if (crispy->pistolstart)
+    {
+        if (crispy->singleplayer)
+        {
+            G_PlayerReborn(0);
+        }
+        else if ((demoplayback || netdemo) && !singledemo)
+        {
+            // no-op - silently ignore pistolstart when playing demo from the
+            // demo reel
+        }
+        else
+        {
+            const char message[] = "The -pistolstart option is not suppported"
+                                   " for demos and\n"
+                                   " network play.";
+            I_Error(message);
+        }
+    }
+
     P_SetupLevel (gameepisode, gamemap, 0, gameskill);    
     displayplayer = consoleplayer;		// view the guy you are playing    
     gameaction = ga_nothing; 
@@ -1651,6 +1673,7 @@ void G_SecretExitLevel (void)
 } 
 
 // [crispy] format time for level statistics
+#define TIMESTRSIZE 16
 static void G_FormatLevelStatTime(char *str, int tics)
 {
     int exitHours, exitMinutes;
@@ -1665,12 +1688,12 @@ static void G_FormatLevelStatTime(char *str, int tics)
 
     if (exitHours)
     {
-        M_snprintf(str, sizeof(str), "%d:%02d:%05.2f",
+        M_snprintf(str, TIMESTRSIZE, "%d:%02d:%05.2f",
                     exitHours, exitMinutes, exitSeconds);
     }
     else
     {
-        M_snprintf(str, sizeof(str), "%01d:%05.2f", exitMinutes, exitSeconds);
+        M_snprintf(str, TIMESTRSIZE, "%01d:%05.2f", exitMinutes, exitSeconds);
     }
 }
 
@@ -1682,8 +1705,8 @@ static void G_WriteLevelStat(void)
     int i, playerKills = 0, playerItems = 0, playerSecrets = 0;
 
     char levelString[8];
-    char levelTimeString[16];
-    char totalTimeString[16];
+    char levelTimeString[TIMESTRSIZE];
+    char totalTimeString[TIMESTRSIZE];
     char *decimal;
 
     if (fstream == NULL)
@@ -1692,7 +1715,7 @@ static void G_WriteLevelStat(void)
 
         if (fstream == NULL)
         {
-            fprintf(stderr, "Unable to open levelstat.txt for writing!\n");
+            fprintf(stderr, "G_WriteLevelStat: Unable to open levelstat.txt for writing!\n");
             return;
         }
     }
@@ -1758,11 +1781,14 @@ void G_DoCompleted (void)
 
         if (gameversion == exe_chex)
         {
+            // [crispy] display tally screen after Chex Quest E1M5
+            /*
             if (gamemap == 5)
             {
                 gameaction = ga_victory;
                 return;
             }
+            */
         }
         else
         {
@@ -2030,7 +2056,7 @@ void G_WorldDone (void)
     }
     // [crispy] display tally screen after ExM8
     else
-    if ( gamemap == 8 )
+    if ( gamemap == 8 || (gameversion == exe_chex && gamemap == 5) )
     {
 	gameaction = ga_victory;
     }
