@@ -1018,6 +1018,19 @@ void D_DoomMain(void)
     D_AddFile(iwadfile);
     W_CheckCorrectIWAD(heretic);
 
+    //!
+    // @category game
+    // @category mod
+    //
+    // Automatic wand start when advancing from one level to the next. At the
+    // beginning of each level, the player's health is reset to 100, their
+    // armor to 0 and their inventory is reduced to the following: wand, staff
+    // and 50 ammo for the wand. This option is not allowed when recording a
+    // demo, playing back a demo or when starting a network game.
+    //
+
+    crispy->pistolstart = M_ParmExists("-wandstart");
+
     //!
     // @category mod
     //
