@@ -108,6 +108,8 @@ int levelstarttic;              // gametic at level start
 int totalkills, totalitems, totalsecret;        // for intermission
 int totalleveltimes; // [crispy] total time for all completed levels
 
+boolean finalintermission; // [crispy] track intermission at end of episode
+
 int mouseSensitivity;
 
 char demoname[32];
@@ -769,6 +771,30 @@ void G_DoLoadLevel(void)
         memset(players[i].frags, 0, sizeof(players[i].frags));
     }
 
+    // [crispy] update the "singleplayer" variable
+    CheckCrispySingleplayer(!demorecording && !demoplayback && !netgame);
+
+    // [crispy] wand start
+    if (crispy->pistolstart)
+    {
+        if (crispy->singleplayer)
+        {
+            G_PlayerReborn(0);
+        }
+        else if (demoplayback && !singledemo)
+        {
+            // no-op - silently ignore pistolstart when playing demo from
+            // the demo reel
+        }
+        else
+        {
+            const char message[] = "The -wandstart option is not supported"
+                                   " for demos and\n"
+                                   " network play.";
+            I_Error(message);
+        }
+    }
+
     P_SetupLevel(gameepisode, gamemap, 0, gameskill);
     displayplayer = consoleplayer;      // view the guy you are playing
     gameaction = ga_nothing;
@@ -1512,6 +1538,7 @@ void G_SecretExitLevel(void)
 }
 
 // [crispy] format time for level statistics
+#define TIMESTRSIZE 16
 static void G_FormatLevelStatTime(char *str, int tics)
 {
     int exitHours, exitMinutes;
@@ -1526,12 +1553,12 @@ static void G_FormatLevelStatTime(char *str, int tics)
 
     if (exitHours)
     {
-        M_snprintf(str, sizeof(str), "%d:%02d:%05.2f",
+        M_snprintf(str, TIMESTRSIZE, "%d:%02d:%05.2f",
                     exitHours, exitMinutes, exitSeconds);
     }
     else
     {
-        M_snprintf(str, sizeof(str), "%01d:%05.2f", exitMinutes, exitSeconds);
+        M_snprintf(str, TIMESTRSIZE, "%01d:%05.2f", exitMinutes, exitSeconds);
     }
 }
 
@@ -1542,8 +1569,8 @@ static void G_WriteLevelStat(void)
 
     int i, playerKills = 0, playerItems = 0, playerSecrets = 0;
 
-    char levelTimeString[16];
-    char totalTimeString[16];
+    char levelTimeString[TIMESTRSIZE];
+    char totalTimeString[TIMESTRSIZE];
     char *decimal;
 
     if (fstream == NULL)
@@ -1552,7 +1579,7 @@ static void G_WriteLevelStat(void)
 
         if (fstream == NULL)
         {
-            fprintf(stderr, "Unable to open levelstat.txt for writing!\n");
+            fprintf(stderr, "G_WriteLevelStat: Unable to open levelstat.txt for writing!\n");
             return;
         }
     }
@@ -1619,8 +1646,8 @@ void G_DoCompleted(void)
     }
     else if (gamemap == 8)
     {
-        gameaction = ga_victory;
-        return;
+        // [crispy] track intermission at end of episode
+        finalintermission = true;
     }
     else
     {
@@ -1643,6 +1670,12 @@ void G_DoCompleted(void)
 void G_WorldDone(void)
 {
     gameaction = ga_worlddone;
+
+    // [crispy] track intermission at end of episode
+    if (finalintermission)
+    {
+        gameaction = ga_victory;
+    }
 }
 
 //============================================================================
@@ -1830,6 +1863,9 @@ void G_InitNew(skill_t skill, int episode, int map)
     // [crispy] total time for all completed levels
     totalleveltimes = 0;
 
+    // [crispy] track intermission at end of episode
+    finalintermission = false;
+
     // Set the sky map
     if (episode > 5)
     {
