@@ -181,7 +181,7 @@ static void LaunchDoom(void *unused1, void *unused2)
 
 static txt_button_t *GetLaunchButton(void)
 {
-    char *label;
+    const char *label;
 
     switch (gamemission)
     {
@@ -312,6 +312,15 @@ static void InitTextscreen(void)
         exit(-1);
     }
 
+    // Set Romero's "funky blue" color:
+    // <https://doomwiki.org/wiki/Romero_Blue>
+    TXT_SetColor(TXT_COLOR_BLUE, 0x04, 0x14, 0x40);
+
+    // [crispy] Crispy colors for Crispy Setup
+    TXT_SetColor(TXT_COLOR_BRIGHT_GREEN, 249, 227, 0);  // 0xF9, 0xE3, 0x00
+    TXT_SetColor(TXT_COLOR_CYAN, 220, 153, 0);          // 0xDC, 0x99, 0x00
+    TXT_SetColor(TXT_COLOR_BRIGHT_CYAN, 76, 160, 223);  // 0x4C, 0xA0, 0xDF
+
     SetIcon();
     SetWindowTitle();
 }
