@@ -2188,7 +2188,7 @@ void G_WriteDemoTiccmd (ticcmd_t* cmd)
 // 
 // [STRIFE] Verified unmodified
 //
-void G_RecordDemo (char* name)
+void G_RecordDemo (const char* name)
 {
     size_t demoname_size;
     int             i;
